# fastai-datasets

<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

# Docs

See https://irad-zehavi.github.io/fastai-datasets/

## Install

``` sh
pip install fastai_datasets
```

## How to use

``` python
from fastai_datasets.mnist import MNIST

MNIST().dls().show_batch()
```

<img src="index_files/figure-commonmark/cell-2-output-1.png"
class="quarto-discovered-preview-image" />
